@@ -2,11 +2,11 @@
 
 #' Mutual information maximisation filter
 #'
-#' Calculates mutual information between all attributes and the decision, then returns top k.
+#' Calculates mutual information between all features and the decision, then returns top k.
 #' @template input
 #' @template y
 #' @template k
-#' @template output-mim
+#' @template output
 #' @examples data(MadelonD)
 #' MIM(MadelonD$X,MadelonD$Y,20)
 #' @export
@@ -15,47 +15,64 @@ MIM<-function(X,Y,k=3,threads=0)
 
 #' Minimal conditional mutual information maximisation filter
 #'
-#' The method starts with an attribute of a maximal mutual information with the decision \eqn{Y}.
-#' Then, it greedily adds attribute \eqn{X} with a maximal value of the following criterion:
+#' The method starts with a feature of a maximal mutual information with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
 #' \deqn{J(X)=\min(I(X;Y),\min_{W\in S} I(X;Y|W)),}
-#' where \eqn{S} is the set of already selected attributes.
-#' @note CMIM is identical to the Informative Fragments (IF) method.
+#' where \eqn{S} is the set of already selected features.
 #' @references "Fast Binary Feature Selection using Conditional Mutual Information Maximisation" F. Fleuret, JMLR (2004)
 #' @references "Object recognition with informative features and linear classification" M. Vidal-Naquet and S. Ullman, IEEE Conference on Computer Vision and Pattern Recognition (2003).
 #' @template input
 #' @template y
 #' @template k
-#' @template output-mim
+#' @template output
 #' @examples data(MadelonD)
 #' CMIM(MadelonD$X,MadelonD$Y,20)
 #' @export
 CMIM<-function(X,Y,k=3,threads=0)
  .Call(C_CMIM,X,Y,as.integer(k),as.integer(threads))
 
-#' Minimum redundancy maximal relevancy filter
+#' Conditional mutual information maximisation filter
 #'
-#' The method starts with an attribute of a maximal mutual information with the decision \eqn{Y}.
-#' Then, it greedily adds attribute \eqn{X} with a maximal value of the following criterion:
-#' \deqn{J(X)=I(X;Y)-\frac{1}{|S|}\sum_{W\in S} I(X;W),}
-#' where \eqn{S} is the set of already selected attributes.
-#' @references "Feature Selection Based on Mutual Information: Criteria of Max-Dependency, Max-Relevance, and Min-Redundancy" H. Peng et al. IEEE Pattern Analysis and Machine Intelligence (PAMI) (2005)
+#' The method starts with a feature of a maximal mutual information with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
+#' \deqn{J(X)=I(X;Y|S),}
+#' where \eqn{S} is the set of already selected features.
 #' @template input
 #' @template y
 #' @template k
 #' @template output
 #' @examples data(MadelonD)
+#' CMI(MadelonD$X,MadelonD$Y,20)
+#' @export
+CMI<-function(X,Y,k=3,threads=0)
+ .Call(C_CMI,X,Y,as.integer(k),as.integer(threads))
+
+#' Minimum redundancy maximal relevancy filter
+#'
+#' The method starts with a feature of a maximal mutual information with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
+#' \deqn{J(X)=I(X;Y)-\frac{1}{|S|}\sum_{W\in S} I(X;W),}
+#' where \eqn{S} is the set of already selected features.
+#' @references "Feature Selection Based on Mutual Information: Criteria of Max-Dependency, Max-Relevance, and Min-Redundancy" H. Peng et al. IEEE Pattern Analysis and Machine Intelligence (PAMI) (2005)
+#' @template input
+#' @template y
+#' @template k
+#' @param positive If true, algorithm won't return features with negative scores (i.e., with redundancy term higher than the relevance therm).
+#'  In that case, \code{k} controls the maximal number of returned features, and is set to `ncol(X)` by default.
+#' @template output
+#' @examples data(MadelonD)
 #' MRMR(MadelonD$X,MadelonD$Y,20)
 #' @export
-MRMR<-function(X,Y,k=3,threads=0)
- .Call(C_MRMR,X,Y,as.integer(k),as.integer(threads))
+MRMR<-function(X,Y,k=if(positive) ncol(X) else 3,positive=FALSE,threads=0)
+ .Call(C_MRMR,X,Y,as.integer(k),as.integer(threads),as.logical(positive))
 
 #' Joint mutual information filter
 #'
-#' The method starts with an attribute of a maximal mutual information with the decision \eqn{Y}.
-#' Then, it greedily adds attribute \eqn{X} with a maximal value of the following criterion:
+#' The method starts with a feature of a maximal mutual information with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
 #' \deqn{J(X)=\sum_{W\in S} I(X,W;Y),}
-#' where \eqn{S} is the set of already selected attributes.
-#' @note \code{\link{DISR}} is a normalised version of JMI; \code{\link{JMIM}} and \code{\link{NJMIM}} are modifications of JMI and DISR in which minimal joint information over already selected attributes is used instead of a sum.
+#' where \eqn{S} is the set of already selected features.
+#' @note \code{\link{DISR}} is a normalised version of JMI; \code{\link{JMIM}} and \code{\link{NJMIM}} are modifications of JMI and DISR in which minimal joint information over already selected features is used instead of a sum.
 #' @references "Data Visualization and Feature Selection: New Algorithms for Nongaussian Data H. Yang and J. Moody, NIPS (1999)
 #' @template input
 #' @template y
@@ -69,11 +86,11 @@ JMI<-function(X,Y,k=3,threads=0)
 
 #' Double input symmetrical relevance filter
 #'
-#' The method starts with an attribute of a maximal mutual information with the decision \eqn{Y}.
-#' Then, it greedily adds attribute \eqn{X} with a maximal value of the following criterion:
+#' The method starts with a feature of a maximal mutual information with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
 #' \deqn{J(X)=\sum_{W\in S} \frac{I(X,W;Y)}{H(X,W,Y)},}
-#' where \eqn{S} is the set of already selected attributes.
-#' @note DISR is a normalised version of \code{\link{JMI}}; \code{\link{JMIM}} and \code{\link{NJMIM}} are modifications of JMI and DISR in which minimal joint information over already selected attributes is used instead of a sum.
+#' where \eqn{S} is the set of already selected features.
+#' @note DISR is a normalised version of \code{\link{JMI}}; \code{\link{JMIM}} and \code{\link{NJMIM}} are modifications of JMI and DISR in which minimal joint information over already selected features is used instead of a sum.
 #' @references "On the Use of Variable Complementarity for Feature Selection in Cancer Classification" P. Meyer and G. Bontempi, (2006)
 #' @template input
 #' @template y
@@ -87,15 +104,15 @@ DISR<-function(X,Y,k=3,threads=0)
 
 #' Minimal joint mutual information maximisation filter
 #'
-#' The method starts with an attribute of a maximal mutual information with the decision \eqn{Y}.
-#' Then, it greedily adds attribute \eqn{X} with a maximal value of the following criterion:
+#' The method starts with a feature of a maximal mutual information with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
 #' \deqn{J(X)=\min_{W\in S} I(X,W;Y),}
-#' where \eqn{S} is the set of already selected attributes.
-#' @note \code{\link{NJMIM}} is a normalised version of JMIM; \code{\link{JMI}} and \code{\link{DISR}} are modifications of JMIM and NJMIM in which a sum of joint information over already selected attributes is used instead of a minimum.
+#' where \eqn{S} is the set of already selected features.
+#' @note \code{\link{NJMIM}} is a normalised version of JMIM; \code{\link{JMI}} and \code{\link{DISR}} are modifications of JMIM and NJMIM in which a sum of joint information over already selected features is used instead of a minimum.
 #' @template input
 #' @template y
 #' @template k
-#' @template output-mim
+#' @template output
 #' @examples data(MadelonD)
 #' JMIM(MadelonD$X,MadelonD$Y,20)
 #' @references "Feature selection using Joint Mutual Information Maximisation" M. Bennasar, Y. Hicks and R. Setchi, (2015)
@@ -105,16 +122,16 @@ JMIM<-function(X,Y,k=3,threads=0)
 
 #' Minimal normalised joint mutual information maximisation filter
 #'
-#' The method starts with an attribute of a maximal mutual information with the decision \eqn{Y}.
-#' Then, it greedily adds attribute \eqn{X} with a maximal value of the following criterion:
+#' The method starts with a feature of a maximal mutual information with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
 #' \deqn{J(X)=\min_{W\in S} \frac{I(X,W;Y)}{H(X,W,Y)},}
-#' where \eqn{S} is the set of already selected attributes.
-#' @note NJMIM is a normalised version of \code{\link{JMIM}}; \code{\link{JMI}} and \code{\link{DISR}} are modifications of JMIM and NJMIM in which a sum of joint information over already selected attributes is used instead of a minimum.
+#' where \eqn{S} is the set of already selected features.
+#' @note NJMIM is a normalised version of \code{\link{JMIM}}; \code{\link{JMI}} and \code{\link{DISR}} are modifications of JMIM and NJMIM in which a sum of joint information over already selected features is used instead of a minimum.
 #' It stops returning features when the best score reaches 0.
 #' @template input
 #' @template y
 #' @template k
-#' @template output-mim
+#' @template output
 #' @examples data(MadelonD)
 #' NJMIM(MadelonD$X,MadelonD$Y,20)
 #' @references "Feature selection using Joint Mutual Information Maximisation" M. Bennasar, Y. Hicks and R. Setchi, (2015)
@@ -124,10 +141,10 @@ NJMIM<-function(X,Y,k=3,threads=0)
 
 #' Joint impurity filter
 #'
-#' The method starts with an attribute of a maximal impurity gain with the decision \eqn{Y}.
-#' Then, it greedily adds attribute \eqn{X} with a maximal value of the following criterion:
+#' The method starts with a feature of a maximal impurity gain with the decision \eqn{Y}.
+#' Then, it greedily adds feature \eqn{X} with a maximal value of the following criterion:
 #' \deqn{J(X)=\sum_{W\in S} G(X,W;Y),}
-#' where \eqn{S} is the set of already selected attributes, and
+#' where \eqn{S} is the set of already selected features, and
 #' \deqn{G(X;Y)=\sum_{xy}\frac{p_{xy}^2}{p_x}-\sum_{y} p_y^2}
 #' is the Gini impurity gain from partitioning \eqn{Y} according to \eqn{X}.
 #' @note This is an impurity-based version of \code{\link{JMI}}; expect similar results in slightly shorter time.
@@ -140,4 +157,3 @@ NJMIM<-function(X,Y,k=3,threads=0)
 #' @export
 JIM<-function(X,Y,k=3,threads=0)
  .Call(C_JIM,X,Y,as.integer(k),as.integer(threads))
-
